package sk.upjs.ics.novotnyr.downloadr;

import java.util.concurrent.TimeUnit;

import android.app.IntentService;
import android.app.Notification;
import android.app.NotificationManager;
import android.app.PendingIntent;
import android.content.Context;
import android.content.Intent;
import android.support.v4.app.NotificationCompat;
import android.util.Log;

public class DownloadService extends IntentService {
	public static final String WORKER_THREAD_NAME = "DownloadServiceThread";
	private static final int DOWNLOAD_NOTIFICATION_COMPLETED_ID = 0;
	
	private static final String LOG_TAG = "DownloadService";
	
	public static final String INTENT_EXTRA_DOWNLOAD_URL = "DOWNLOAD_URL";
	
	public DownloadService() {
		super(WORKER_THREAD_NAME);
	}
  
	@Override
	public void onCreate() {
		super.onCreate();
		
		Log.i(LOG_TAG, "Download service created");
	}
	
	@Override
	public void onDestroy() {
		Log.i(LOG_TAG, "Download service destroyed");

		super.onDestroy();
	}
	
	@Override
	protected void onHandleIntent(Intent intent) {
		String downloadUrl = intent.getStringExtra(INTENT_EXTRA_DOWNLOAD_URL);;
		notifyCompleted(download(downloadUrl));		
	}
	
	private boolean download(String url) {
		boolean isSuccessfullyCompleted = true;

		for(long i = 1; i <= 100; i = i + 5) {
			try {
				TimeUnit.MILLISECONDS.sleep(100);
				Log.i(LOG_TAG, "Download: " + i + "%");
			} catch (InterruptedException e) {
				isSuccessfullyCompleted = false;
				break;
			}
		}
		
		return isSuccessfullyCompleted;
	}

	private void notifyCompleted(boolean isSuccessful) {
		
		String text = isSuccessful ? "Download completed" : "Download failed";
		
   	    NotificationManager notificationManager = (NotificationManager) getSystemService(Context.NOTIFICATION_SERVICE);		
   	    Notification notification = new NotificationCompat.Builder(getApplicationContext())
		   .setContentTitle("Download is completed")
		   .setContentText(text)
		   .setContentIntent(getEmptyNotificationContentIntent())
		   .setTicker(text)
		   .setDefaults(Notification.DEFAULT_SOUND)
		   .setAutoCancel(true)
		   .setSmallIcon(R.drawable.ic_launcher)
		   .build();

   	    String tag = Long.toString(System.currentTimeMillis());

		notificationManager.notify(tag, DOWNLOAD_NOTIFICATION_COMPLETED_ID, notification);		
	}

	private PendingIntent getEmptyNotificationContentIntent() {
		int REQUEST_CODE = 0;
		int NO_FLASG = 0;

		PendingIntent contentIntent = PendingIntent.getActivity(getApplicationContext(), REQUEST_CODE, new Intent(), NO_FLASG);
		return contentIntent;
	}
}
